Mutex

Struct Mutex 

pub struct Mutex<T> { /* private fields */ }

Implementations

Source

impl<T> Mutex<T>

pub const fn new(content: T) -> Self

Create a new mutex

pub unsafe fn locked(content: T) -> Self

Create a new mutex that is already locked. This is a more efficient way to do the following:

let mut mutex = Mutex::new(());
mutex.manual_lock();
pub unsafe fn manual_try_lock(&self) -> Result<&mut T, c_int>

Tries to lock the mutex, fails if it’s already locked. Manual means it’s up to you to unlock it after mutex. Returns the last atomic value on failure. You should probably not worry about this, it’s used for internal optimizations.

pub unsafe fn manual_lock(&self) -> &mut T

Lock the mutex, returning the inner content. After doing this, it’s your responsibility to unlock it after usage. Mostly useful for FFI: Prefer normal .lock() where possible.

pub unsafe fn manual_unlock(&self)

Unlock the mutex, if it’s locked.

pub fn as_ptr(&self) -> *mut T

pub fn try_lock(&self) -> Option<MutexGuard<'_, T>>

Tries to lock the mutex and returns a guard that automatically unlocks the mutex when it falls out of scope.

pub fn lock(&self) -> MutexGuard<'_, T>

Locks the mutex and returns a guard that automatically unlocks the mutex when it falls out of scope.